@@ -1,5 +1,5 @@
 # from . import tools, tt_api
 
-__all__ = ['tools', 'tt_api']
+__all__ = ['tools', 'tt_api', 'ocs_api']
 
 name = 'pywayne'
